magneticalc.Usage_Dialog.Usage_Dialog

# ``magneticalc`.`Usage_Dialog`.`Usage_Dialog``

class documentation

`class Usage_Dialog(QDialog2):`

Constructor: `Usage_Dialog()`

View In Hierarchy

Usage_Dialog class.

Method | `__init__` | Initializes "Usage" dialog.
Constant | `HTML` | Undocumented

Inherited from `QDialog2`:

Method | `show` | Shows this dialog.
Method | `showEvent` | Gets called when the dialog is opened.
Instance Variable | `user_accepted` | Undocumented

Inherited from `QLayouted` (via `QDialog2`):

Method | `addButtons` | Adds buttons.
Method | `addLayout` | Adds layout.
Method | `addSpacing` | Adds spacing.
Method | `addWidget` | Adds widget.
Method | `install_layout` | Installs this layout in the parent.
Instance Variable | `_layout` | Undocumented

def __init__(self):
overrides `magneticalc.QtWidgets2.QDialog2.QDialog2.__init__`

Initializes "Usage" dialog.

HTML =

Undocumented

Value
    f"""\n        <h3 style="color: {Theme.MainColor};">First Steps</h3>\n        <h↵
    4>\n            MagnetiCalc loads a very simple magnetic setup by default.<br>\n↵
                Follow these steps to turn it into your own custom setup:\n        <↵
    /h4>\n        <ul>\n            <li>\n                Go to <i>Wire</i> › <i>Loa↵
    d Preset</i> to select a basic wire shape.<br>\n                (But you could a↵
    lso import/export wire points from/to a TXT file.)\n            </li>\n        <↵
    /ul>\n        <ul>\n            <li>\n                Customize the wire's base ↵
    ...